Skip to contents

A data frame tha matches the STATECD column used in FIA data to the two letter state abbreviations and the total land area of the state in acres.

Usage

state_areas

Format

An object of class spec_tbl_df (inherits from tbl_df, tbl, data.frame) with 50 rows and 3 columns.