This is an "internal" function—most users will want to run fia_annualize()
instead. Trees in the input data_interpolated already have had their switch
to STATUSCD 2 (i.e. death) interpolated to the midpoint (rounded down)
between it's last survey alive and first survey dead.
Arguments
- data_interpolated
tibble created by
interpolate_data()- use_mortyr
logical; use
MORTYR(if recorded) as the first year a tree was dead?
Details
This does the following:
Optionally figures out if a tree has a recorded
MORTYRand uses that for the transition toSTATUSCD2 instead of the interpolated values. If the tree is alive (STATUSCD1) inMORTYR, then it is assumed it died in the following year.Adjusts
STANDING_DEAD_CDso that it only applies to dead treesAdjusts
DECAYCDso that it only applies to standing dead treesAdjusts
DIA,HT,ACTUALHT,CULL, andCRso that they only apply to live or standing dead trees in sampled conitions.