Converts tidied panel data into annualized data with interpolated measurments
for trees for years between inventories. This happens in three steps, which
can be "manually" replicated by chaining other forestTIME
functions.
Arguments
- data_tidy
A tibble produced by
fia_tidy().- use_mortyr
logical; Use
MORTYR(if recorded) as the first year a tree was dead? Passed toadjust_mortality().
Details
First, data is expanded by expand_data() to add rows for years between
inventories for each tree in the data. Next, data is interpolated with
interpolate_data(). Finally, adjust_mortality() is applied. For trees
that die and/or fall between inventories, we adjust their history according
either to a recorded MORTYR (if use_morty = TRUE) or, as a fall-back, the
midpoint between surveys, rounded down. Unlike these intermediate functions,
fia_annualize() produces a dataset which can be safely used for other
analyses (with the caveat that all of this is experimental).
Note
Most users should use this "wrapper" function rather than running each
step separately since the intermediate steps may contain data artifacts.
However, one reason to use the stepwise workflow would be to save time when
generating interpolated data with and without using MORTYR as
interpolate_data() is the slowest step.
See also
For more details on each step, see: expand_data(),
interpolate_data(), adjust_mortality()
Examples
if (FALSE) { # \dontrun{
db <- db <- fia_load("RI", dir = system.file("exdata", package = "forestTIME"))
data_tidy <- fia_tidy(db)
data_annualized <- fia_annualize(data_tidy)
} # }