Assign interpolated data plots to estimation units and strata
Source:R/fia_assign_strata.R
fia_assign_strata.RdThis adds columns from various POP_* tables to annualized data so that it
can be used for stratified estimation (see, for example, FIA Demystified).
Each plot in each year is matched with an EVALID and it's associated data as
such:
The EVALID must have both the
"EXPVOL"and"EXPCURR"EVAL_TYP.The
YEARmust be betweenSTART_INVYRandEND_INVYR.The first matching EVALID is used—i.e. if the
YEARis 2002 and there are EVALIDs for 2000–2003, 2001–2004, and 2002–2005, the one from 2000–2003 will be matched.
Arguments
- data_annualized
Annualized data produced by
fia_annualize().- db
The list of tables produced by
fia_load().
Details
EVALID-associated data added by this function may be in conflict with the
results of interpolation by fia_annualize()! When using this function to
do stratified estimation, use the PLOT_STATUS_CD as part of the domain
indicator to correctly exclude any non-sampled plots with no tree data!
See also
fia_eval_info() to see all possible EVALIDs associated with plots.
Examples
if (FALSE) { # \dontrun{
# Load example data included in package
db <- fia_load("RI", dir = system.file("exdata", package = "forestTIME"))
# Annualize data
data_annualized <- db |> fia_tidy() |>
fia_annualize(use_mortyr = FALSE)
# Assign plots to strata, estimation units, and EVLIDs
data_stratified <- fia_assign_strata(data_annualized, db)
} # }