Wrapper for rFIA::readFIA() that reads in the necessary tables
Arguments
- states
character; state/ US territory abbreviations (e.g. 'AL', 'MI', etc.) indicating which state subsets to read. Data for each state must be in
dir. Choose to read multiple states by passing character vector of state abbreviations (e.g.states = c('RI', 'CT', 'MA')). Ifstates = NULL, data for all states withindirwill be read in and merged into a regional database.- dir
directory where .csv files of FIA tables are stored.
Examples
if (FALSE) { # \dontrun{
fia_download(states = "RI")
RI_db <- fia_load("RI")
} # }